- Added the module ``xoutil.records``.

- Deleted deprecated ``xoutil.compat``.


- Deprecate the ``xoutil.six``.  It will removed in 1.7.0 (probably next
  release).

  Now xoutil requires `six` 1.8.0.
